@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: cfgmoduleqbm.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: cfgmoduleqbm.h,v 1.1 2006/01/09 22:40:04 aquamaniac Exp $
+    cvs         : $Id: cfgmoduleqbm.h 347 2006-01-09 22:40:04Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
