@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: assigncategories.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: assigncategories.h,v 1.2 2005/08/31 05:24:20 aquamaniac Exp $
+    cvs         : $Id: assigncategories.h 301 2005-08-31 05:24:20Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
