@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: assignpayees.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: assignpayees.cpp,v 1.7 2005/11/03 00:36:01 aquamaniac Exp $
+    cvs         : $Id: assignpayees.cpp 333 2005-11-03 00:36:01Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
