@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: assignpayees.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: assignpayees.h,v 1.1 2005/02/23 02:15:33 aquamaniac Exp $
+    cvs         : $Id: assignpayees.h 150 2005-02-23 02:15:34Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
