@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: editeutransaction.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: editeutransaction.cpp,v 1.14 2005/10/02 14:05:27 cstim Exp $
+    cvs         : $Id: editeutransaction.cpp 330 2005-10-02 14:05:27Z cstim $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
