@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: edittransaction.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: edittransaction.cpp,v 1.33 2005/12/23 02:44:58 aquamaniac Exp $
+    cvs         : $Id: edittransaction.cpp 344 2005-12-23 02:44:58Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
