@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: exportedit.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: exportedit.cpp,v 1.11 2006/03/08 15:38:34 aquamaniac Exp $
+    cvs         : $Id: exportedit.cpp 388 2006-03-08 15:38:34Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
