@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: ruleeditor.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: ruleeditor.cpp,v 1.6 2005/10/24 11:36:25 aquamaniac Exp $
+    cvs         : $Id: ruleeditor.cpp 332 2005-10-24 11:36:25Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
