@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: ruleeditor.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: ruleeditor.h,v 1.2 2005/08/30 07:52:41 aquamaniac Exp $
+    cvs         : $Id: ruleeditor.h 300 2005-08-30 07:52:41Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
