@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: rulenameedit.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: rulenameedit.h,v 1.1 2004/11/21 09:36:38 aquamaniac Exp $
+    cvs         : $Id: rulenameedit.h 94 2004-11-21 09:36:38Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
