@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: settings.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: settings.cpp,v 1.20 2005/11/25 16:49:40 cstim Exp $
+    cvs         : $Id: settings.cpp 337 2005-11-25 16:49:41Z cstim $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
