@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: settings.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: settings.h,v 1.5 2005/08/24 16:52:02 aquamaniac Exp $
+    cvs         : $Id: settings.h 277 2005-08-24 16:52:02Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
