@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: transfinder.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: transfinder.h,v 1.11 2006/01/27 08:33:20 aquamaniac Exp $
+    cvs         : $Id: transfinder.h 376 2006-01-27 08:33:20Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
