@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: mainwindow.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: mainwindow.cpp,v 1.47 2006/02/09 14:11:06 aquamaniac Exp $
+    cvs         : $Id: mainwindow.cpp 384 2006-02-09 14:11:06Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
