@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: mainwindow.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: mainwindow.h,v 1.24 2005/11/07 19:28:00 aquamaniac Exp $
+    cvs         : $Id: mainwindow.h 334 2005-11-07 19:28:00Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
