@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: account.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: account.cpp,v 1.28 2006/03/10 02:20:52 aquamaniac Exp $
+    cvs         : $Id: account.cpp 393 2006-03-22 16:32:29Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -32,7 +32,7 @@ Account::Account(App *app)
 ,_optionUpdateBalance(true)
 ,_optionUpdateStandingOrders(true)
 ,_optionUpdateDatedTransfers(true)
-,_optionUpdatePending(true)
+,_optionUpdatePending(false)
 ,_optionExcludeFromGlobalCall(false)
 ,_storage(0)
 ,_lastTransactionDate(0) {
@@ -50,7 +50,7 @@ Account::Account(App *app, const AB_ACCOUNT *a)
 ,_optionUpdateBalance(true)
 ,_optionUpdateStandingOrders(true)
 ,_optionUpdateDatedTransfers(true)
-,_optionUpdatePending(true)
+,_optionUpdatePending(false)
 ,_optionExcludeFromGlobalCall(false)
 ,_storage(0)
 ,_lastTransactionDate(0){
@@ -93,7 +93,7 @@ Account::Account(const Account &a)
 ,_optionUpdateBalance(true)
 ,_optionUpdateStandingOrders(true)
 ,_optionUpdateDatedTransfers(true)
-,_optionUpdatePending(true)
+,_optionUpdatePending(false)
 ,_optionExcludeFromGlobalCall(false)
 ,_storage(0){
   _bankCode=a._bankCode;
@@ -199,7 +199,7 @@ bool Account::fromDb(GWEN_DB_NODE *db) {
                                                     0, 1);
     _optionUpdatePending=GWEN_DB_GetIntValue(dbT,
                                              "updatePending",
-                                             0, 1);
+                                             0, 0);
     _optionExcludeFromGlobalCall=GWEN_DB_GetIntValue(dbT,
                                                      "excludeFromGlobalCall",
                                                      0, 0);
