@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: app.cpp,v $
                              -------------------
-    cvs         : $Id: app.cpp,v 1.56 2006/03/08 15:38:34 aquamaniac Exp $
+    cvs         : $Id: app.cpp 396 2006-05-29 17:00:16Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -765,20 +765,27 @@ Account *App::findAccount(const char *bankCode,
                           const char *accountNumber) {
   std::list<Account*>::iterator it;
   GWEN_TYPE_UINT64 an;
+  Account *a=0;
 
   if (!bankCode)
-    bankCode="";
+    bankCode="*";
   if (!accountNumber)
-    accountNumber="";
+    accountNumber="*";
 
   for (it=_accounts.begin(); it!=_accounts.end(); it++) {
-    if ((strcasecmp((*it)->getBankCode().c_str(),
-                    bankCode)==0) &&
-        (strcasecmp((*it)->getAccountNumber().c_str(),
-                    accountNumber)==0))
-      return *it;
+    if ((-1!=GWEN_Text_ComparePattern((*it)->getBankCode().c_str(),
+                                      bankCode, 0)) &&
+        (-1!=GWEN_Text_ComparePattern((*it)->getAccountNumber().c_str(),
+                                      accountNumber, 0))) {
+      if (a) {
+        DBG_ERROR(0, "Ambiguous account specification");
+        return 0;
+      }
+      a=*it;
+    }
   }
-
+  if (a)
+    return a;
 
   an=char2uint64(accountNumber);
   if (an) {
