@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: app.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: app.h,v 1.32 2006/03/08 15:38:34 aquamaniac Exp $
+    cvs         : $Id: app.h 388 2006-03-08 15:38:34Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
