@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: refpointer.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: refpointer.h,v 1.4 2005/09/07 15:38:38 aquamaniac Exp $
+    cvs         : $Id: refpointer.h 314 2005-09-07 15:38:38Z aquamaniac $
     begin       : Tue Dec 13 2001
     copyright   : (C) 2001 by Martin Preuss
     email       : martin@aquamaniac.de
