@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: timport.cpp,v $
                              -------------------
-    cvs         : $Id: timport.cpp,v 1.30 2006/03/08 15:38:34 aquamaniac Exp $
+    cvs         : $Id: timport.cpp 396 2006-05-29 17:00:16Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -510,7 +510,7 @@ TransactionImporter::_checkDay(Account *a,
       GWEN_TIME *nti;
 
       DBG_DEBUG(0, "Setting new date");
-      // set UTC date, 12 o'clock (in this case: UTC date==local date
+      // set UTC date, 12 o'clock (in this case: UTC date==local date)
       nti=GWEN_Time_new(d->getYear(), d->getMonth()-1, d->getDay(),
                         12, 0, 0, 1);
       assert(nti);
@@ -953,6 +953,9 @@ bool TransactionImporter::importAccounts(){
                         AB_ImExporterAccountInfo_GetAccountNumber(ai));
     if (!a) {
       /* account not found, TODO: ask the user to add it */
+      DBG_ERROR(0, "Account \"%s/%s\" not found",
+                AB_ImExporterAccountInfo_GetBankCode(ai),
+                AB_ImExporterAccountInfo_GetAccountNumber(ai));
     }
     else {
       AB_ACCOUNT_STATUS *bestBooked;
@@ -963,7 +966,7 @@ bool TransactionImporter::importAccounts(){
       bestNoted=_getBestBalance(ai, true);
 
       if (bestBooked) {
-	if (AB_AccountStatus_GetNotedBalance(bestBooked)==0) {
+        if (AB_AccountStatus_GetNotedBalance(bestBooked)==0) {
 	  if (bestNoted) {
 	    const AB_BALANCE *bestNotedBalance;
 
@@ -974,7 +977,7 @@ bool TransactionImporter::importAccounts(){
 	a->setAccountStatus(bestBooked);
       }
       else if (bestNoted) {
-	a->setAccountStatus(bestNoted);
+        a->setAccountStatus(bestNoted);
       }
     }
     ai=AB_ImExporterContext_GetNextAccountInfo(_context);
@@ -1030,7 +1033,9 @@ bool TransactionImporter::importDatedTransfers(){
                         AB_ImExporterAccountInfo_GetAccountNumber(ai));
     if (!a) {
       /* account not found, TODO: ask the user to add it */
-      DBG_ERROR(0, "Account not found");
+      DBG_ERROR(0, "Account \"%s/%s\" not found",
+                AB_ImExporterAccountInfo_GetBankCode(ai),
+                AB_ImExporterAccountInfo_GetAccountNumber(ai));
     }
     else {
       const AB_TRANSACTION *t;
@@ -1098,6 +1103,8 @@ TransactionImporter::getAccountData(const char *s1,
 
   if (!bankCode.empty() && !accountNumber.empty())
     a=_app->findAccount(bankCode.c_str(), accountNumber.c_str());
+  else if (bankCode.empty() && !accountNumber.empty())
+    a=_app->findAccount("*", accountNumber.c_str());
   if (!a) {
     // TODO: check for aliases
     // TODO: ask the user for alias
