@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: transaction.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: transaction.cpp,v 1.26 2006/01/28 11:13:57 aquamaniac Exp $
+    cvs         : $Id: transaction.cpp 396 2006-05-29 17:00:16Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -1168,6 +1168,7 @@ std::string Transaction::toHtmlInfo() const {
   v=getValue();
   if (v) {
     char numbuf[32];
+    const char *s;
 
     if (AB_Value_GetValue(v)>0)
       tmp+="<font color=\"dark green\">";
@@ -1181,8 +1182,11 @@ std::string Transaction::toHtmlInfo() const {
     snprintf(numbuf, sizeof(numbuf), "%.2lf", AB_Value_GetValue(v));
 #endif
     tmp+=numbuf;
-    tmp+=" ";
-    tmp+=AB_Value_GetCurrency(v);
+    s=AB_Value_GetCurrency(v);
+    if (s) {
+      tmp+=" ";
+      tmp+=s;
+    }
     tmp+="</font>";
   }
   tmp+="</td>\n";
