@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: transaction.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: transaction.h,v 1.16 2006/01/28 11:13:57 aquamaniac Exp $
+    cvs         : $Id: transaction.h 377 2006-01-28 11:13:57Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
