@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: xastorage.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: xastorage.c,v 1.9 2006/03/08 15:38:34 aquamaniac Exp $
+    cvs         : $Id: xastorage.c 388 2006-03-08 15:38:34Z aquamaniac $
     begin       : Mon Apr 05 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
