@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: report.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: report.h,v 1.4 2006/01/14 02:06:58 aquamaniac Exp $
+    cvs         : $Id: report.h 355 2006-01-14 02:07:00Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
