@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: editsummaryreport.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: editsummaryreport.h,v 1.2 2006/01/24 01:01:48 aquamaniac Exp $
+    cvs         : $Id: editsummaryreport.h 365 2006-01-24 01:01:49Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
