@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: graphreport.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: graphreport.cpp,v 1.11 2006/02/08 15:03:39 cstim Exp $
+    cvs         : $Id: graphreport.cpp 383 2006-02-08 15:03:39Z cstim $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
