@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: greportwidget.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: greportwidget.cpp,v 1.2 2006/01/16 23:08:37 aquamaniac Exp $
+    cvs         : $Id: greportwidget.cpp 358 2006-01-16 23:08:37Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
