@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: summaryreport.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: summaryreport.cpp,v 1.11 2006/01/24 01:01:48 aquamaniac Exp $
+    cvs         : $Id: summaryreport.cpp 365 2006-01-24 01:01:49Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
