@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: categoryview.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: categoryview.cpp,v 1.10 2006/02/08 15:03:39 cstim Exp $
+    cvs         : $Id: categoryview.cpp 383 2006-02-08 15:03:39Z cstim $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
