@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: introviewtextbrowser.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: introviewtextbrowser.h,v 1.1 2005/06/13 12:57:21 cstim Exp $
+    cvs         : $Id: introviewtextbrowser.h 225 2005-06-13 12:57:21Z cstim $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
