@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: jobview.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: jobview.cpp,v 1.27 2006/02/14 13:23:12 aquamaniac Exp $
+    cvs         : $Id: jobview.cpp 385 2006-02-14 13:23:12Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
