@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: payeeview.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: payeeview.cpp,v 1.6 2005/11/25 16:49:41 cstim Exp $
+    cvs         : $Id: payeeview.cpp 337 2005-11-25 16:49:41Z cstim $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
