@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: reportview.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: reportview.h,v 1.1 2005/02/21 00:27:36 aquamaniac Exp $
+    cvs         : $Id: reportview.h 137 2005-02-21 00:27:36Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
