@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: transactionview.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: transactionview.cpp,v 1.27 2006/03/10 02:20:52 aquamaniac Exp $
+    cvs         : $Id: transactionview.cpp 389 2006-03-10 02:20:53Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
