@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: transactionwindow.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: transactionwindow.cpp,v 1.12 2005/09/20 13:35:49 cstim Exp $
+    cvs         : $Id: transactionwindow.cpp 329 2005-09-20 13:35:49Z cstim $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
