@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: transferview.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: transferview.h,v 1.10 2005/09/07 15:38:38 aquamaniac Exp $
+    cvs         : $Id: transferview.h 314 2005-09-07 15:38:38Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
