@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: categorylist.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: categorylist.h,v 1.6 2005/09/05 05:13:21 aquamaniac Exp $
+    cvs         : $Id: categorylist.h 309 2005-09-05 05:13:21Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
