@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: payeelist.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: payeelist.cpp,v 1.4 2006/01/17 22:32:57 aquamaniac Exp $
+    cvs         : $Id: payeelist.cpp 360 2006-01-17 22:32:57Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
