@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: textmatcher.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: textmatcher.h,v 1.1 2005/08/26 02:45:39 aquamaniac Exp $
+    cvs         : $Id: textmatcher.h 284 2005-08-26 02:45:39Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
