@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: transactionlist.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: transactionlist.cpp,v 1.23 2006/01/11 13:15:50 aquamaniac Exp $
+    cvs         : $Id: transactionlist.cpp 349 2006-01-11 13:15:50Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
