@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: transactionlist.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: transactionlist.h,v 1.10 2006/01/11 13:15:50 aquamaniac Exp $
+    cvs         : $Id: transactionlist.h 349 2006-01-11 13:15:50Z aquamaniac $
     begin       : Fri Jul 12 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@aquamaniac.de
